@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006-2008 Vlad Vasiliev
- * Copyright (C) 2006-2008 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * Copyright (C) 2008      Andrew Olmsted
  * 	for the code
  *        
@@ -154,10 +154,8 @@ void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
 		*station_code = NULL,
 		*station_source = NULL;
 #ifdef ENABLE_GPS
-#ifdef OS2008
     gboolean	is_gps = FALSE;
 #endif
-#endif
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -178,7 +176,6 @@ void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
             temp3 = strtok(NULL, "@");
             if (temp3)
                 station_source = g_strdup(temp3);
-#ifdef OS2008
 #ifdef ENABLE_GPS
             if (app->gps_station.id0 && app->gps_station.name &&
                 station_code && station_name &&
@@ -187,13 +184,12 @@ void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
                 is_gps = TRUE;
             else
                 is_gps = FALSE;
-#endif
 #endif
             if (station_name && station_code) {
                 /* Add station to stations list */
                 gtk_list_store_append(*list, &iter);
                 gtk_list_store_set(*list, &iter,
-#if defined(OS2008) && defined(ENABLE_GPS)
+#if defined(ENABLE_GPS)
                                    NAME_COLUMN, station_name,
                                    ID0_COLUMN, station_code,
                                    2, is_gps,
@@ -206,11 +202,11 @@ void fill_user_stations_list(GSList * source_list, GtkListStore ** list) {
                                    -1);
             }
             if (!strcmp(station_name, app->config->current_station_name)
-                && !strcmp(station_code, app->config->current_station_id)) {
-                app->config->current_station_id = g_strdup(station_code);
-                app->config->current_station_name = g_strdup(station_name);
+                && !strcmp(station_code, app->config->current_station_id)
+                && !app->config->current_station_source) {
                 app->config->current_station_source = g_strdup(station_source);
             }
+
             station_name && (g_free(station_name), station_name = NULL);
             station_code && (g_free(station_code), station_code = NULL);
             station_source && (g_free(station_source), station_source = NULL);
@@ -291,6 +287,7 @@ gint read_config(AppletConfig * config) {
     GSList *stlist = NULL;
     GError *gerror = NULL;
     GdkColor DEFAULT_FONT_COLOR = { 0, 0xFF00, 0xFF00, 0x0000 };
+    GdkColor DEFAULT_BACKGROUND_FONT_COLOR = { 0, 0x0000, 0x0000, 0x0000 };
     gchar tmp_buff[1024], *home_dir, *tmp = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
@@ -358,10 +355,9 @@ gint read_config(AppletConfig * config) {
                                                   GCONF_KEY_CURRENT_STATION_SOURCE,
                                                   NULL);
     if (config->current_station_source
-	&& strlen(config->current_station_source) == 0)
+        && strlen(config->current_station_source) == 0)
         config->current_station_source = NULL;
     /* Get GPS station name and id */
-#ifdef OS2008
 #ifdef ENABLE_GPS
     app->gps_station.name[0] = 0;
     tmp = NULL;
@@ -382,7 +378,6 @@ gint read_config(AppletConfig * config) {
         g_free(tmp);
         tmp = NULL;
     }
-#endif
 #endif
     /* Get user Weather Stations list */
     stlist = gconf_client_get_list(gconf_client,
@@ -436,7 +431,7 @@ gint read_config(AppletConfig * config) {
     remove_periodic_event();    /* delete event from list */
     add_periodic_event(time(NULL));     /* add new event */
 
-#ifdef OS2008
+#ifdef ENABLE_GPS
     /* Get gps_station. Default is FALSE */
     value =
         gconf_client_get(gconf_client, GCONF_KEY_USE_GPS_STATION, NULL);
@@ -472,7 +467,7 @@ gint read_config(AppletConfig * config) {
                                   GCONF_KEY_WEATHER_BACKGROUND_COLOR,
                                   NULL);
     if (!tmp || !gdk_color_parse(tmp, &(config->background_color)))
-        config->background_color = DEFAULT_FONT_COLOR;
+        config->background_color = DEFAULT_BACKGROUND_FONT_COLOR;
     g_free(tmp);
     tmp = NULL;
 #if !defined OS2008 || !defined OS2009
@@ -752,23 +747,30 @@ void config_update_proxy(void) {
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    if (app->config->iap_http_proxy_host)
-        g_free(app->config->iap_http_proxy_host);
-    /* Get proxy data */
-    if (gconf_client_get_bool(gconf_client, GCONF_KEY_HTTP_PROXY_ON, NULL)) {
-        /* HTTP Proxy is on. */
-        app->config->iap_http_proxy_host =
-            gconf_client_get_string(gconf_client,
+    gchar *proxy_mode;
+    proxy_mode = gconf_client_get_string(gconf_client,
+                                    GCONF_KEY_PROXY_MODE, NULL);
+
+    if (strcmp(proxy_mode, "none") != 0){
+        if (app->config->iap_http_proxy_host)
+            g_free(app->config->iap_http_proxy_host);
+        /* Get proxy data */
+        if (gconf_client_get_bool(gconf_client, GCONF_KEY_HTTP_PROXY_ON, NULL)) {
+            /* HTTP Proxy is on. */
+            app->config->iap_http_proxy_host =
+                gconf_client_get_string(gconf_client,
                                     GCONF_KEY_HTTP_PROXY_HOST, NULL);
-        app->config->iap_http_proxy_port =
-            gconf_client_get_int(gconf_client, GCONF_KEY_HTTP_PROXY_PORT,
+            app->config->iap_http_proxy_port =
+                gconf_client_get_int(gconf_client, GCONF_KEY_HTTP_PROXY_PORT,
                                  NULL);
-    } else {                    /* HTTP Proxy is off. */
-        app->config->iap_http_proxy_host = NULL;
-        app->config->iap_http_proxy_port = 0;
+        } else {                    /* HTTP Proxy is off. */
+            app->config->iap_http_proxy_host = NULL;
+            app->config->iap_http_proxy_port = 0;
+        }
     }
     g_object_unref(gconf_client);
-
+    g_free(proxy_mode);
+    
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -999,7 +1001,6 @@ void config_save(AppletConfig * config) {
     /* Free stlist */
     g_slist_foreach(stlist, (GFunc) g_free, NULL);
     g_slist_free(stlist);
-#ifdef OS2008
 #ifdef ENABLE_GPS
     /* Save current GPS station */
     if (config->gps_station) {
@@ -1012,7 +1013,6 @@ void config_save(AppletConfig * config) {
                                     GCONF_KEY_GPS_STATION_ID,
                                     app->gps_station.id0, NULL);
     }
-#endif
 #endif
     g_object_unref(gconf_client);
 }
