@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006-2008 Vlad Vasiliev
- * Copyright (C) 2006-2008 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -32,7 +32,6 @@
 #include <conic/conic.h>
 #define USER_DATA_MAGIC 0xaadcaadc
 #endif
-#define GCONF_KEY_CURRENT_CONNECTIVITY	"/system/osso/connectivity/IAP/current"
 #ifdef RELEASE
 #undef DEBUGFUNCTIONCALL
 #endif
@@ -55,7 +54,7 @@ GtkWidget *create_window_update(void) {
                                         NULL, _("Update weather"));
 }
 /*******************************************************************************/
-#ifdef USE_DBUS
+#if !defined OS2008 && !defined OS2009
 static DBusHandlerResult
 get_connection_status_signal_cb(DBusConnection * connection,
                                 DBusMessage * message, void *user_data) {
@@ -107,7 +106,7 @@ get_connection_status_signal_cb(DBusConnection * connection,
 /* Callback function for request  connection to Internet */
 #ifdef USE_CONIC
 #define OSSO_CON_IC_CONNECTING             0x05
-static void
+void
 connection_cb(ConIcConnection * connection,
               ConIcConnectionEvent * event, gpointer user_data) {
     const gchar *iap_id, *bearer;
@@ -181,76 +180,6 @@ void iap_callback(struct iap_event_t *event, void *arg) {
 }
 #endif
 #endif
-/*******************************************************************************/
-void weather_initialize_dbus(void) {
-
-    gchar *tmp;
-#ifdef USE_DBUS
-    gchar *filter_string;
-    DBusConnection *dbus_conn;
-#endif
-    GConfClient *gconf_client = NULL;
-#ifdef DEBUGFUNCTIONCALL
-    START_FUNCTION;
-#endif
-    if (!app->dbus_is_initialize) {
-        /* Reseting values */
-        app->iap_connecting = FALSE;
-        app->iap_connected = FALSE;
-        app->iap_connecting_timer = 0;
-
-        /* Check connection */
-        gconf_client = gconf_client_get_default();
-        if (gconf_client) {
-            tmp = gconf_client_get_string(gconf_client,
-                                          GCONF_KEY_CURRENT_CONNECTIVITY,
-                                          NULL);
-            if (tmp) {
-                app->iap_connected = TRUE;
-                g_free(tmp);
-            } else
-                app->iap_connected = FALSE;
-            gconf_client_clear_cache(gconf_client);
-            g_object_unref(gconf_client);
-        }
-#ifdef USE_CONIC
-        app->connection = con_ic_connection_new();
-        if (app->connection != NULL) {
-            g_object_set(app->connection, "automatic-connection-events",
-                         TRUE, NULL);
-            g_signal_connect(G_OBJECT(app->connection),
-                             "connection-event",
-                             G_CALLBACK(connection_cb),
-                             GINT_TO_POINTER(USER_DATA_MAGIC));
-        }
-#else
-    #ifndef NONMAEMO
-        osso_iap_cb(iap_callback);
-    #endif
-#endif
-
-#ifdef USE_DBUS
-        /* Add D-BUS signal handler for 'status_changed' */
-        dbus_conn = dbus_bus_get(DBUS_BUS_SYSTEM, NULL);
-        filter_string =
-            g_strdup_printf("interface=%s", ICD_DBUS_INTERFACE);
-        /* add match */
-        dbus_bus_add_match(dbus_conn, filter_string, NULL);
-        g_free(filter_string);
-        /* add the callback */
-        dbus_connection_add_filter(dbus_conn,
-                                   get_connection_status_signal_cb,
-                                   NULL, NULL);
-
-#endif                          /* USE_DBUS */
-        /* For Debug on i386 */
-#if ! defined (RELEASE) || defined (NONMAEMO)
-        app->iap_connected = TRUE;
-#endif
-        app->dbus_is_initialize = TRUE;
-    }
-}
-/*******************************************************************************/
 /* Init easy curl */
 CURL *weather_curl_init(CURL * my_curl_handle) {
 #ifdef DEBUGFUNCTIONCALL
@@ -338,8 +267,10 @@ gboolean download_html(gpointer data) {
         if (app->connection)
             con_ic_connection_connect(app->connection,
                                       CON_IC_CONNECT_FLAG_NONE);
-        else
+        else{
+            app->flag_updating = 0;
             return FALSE;
+        }
 #else
     #ifndef NONMAEMO
         if (osso_iap_connect
@@ -369,6 +300,7 @@ gboolean download_html(gpointer data) {
                 app->iap_connecting_timer = 0;
             }
             app->iap_connecting = FALSE;
+            app->flag_updating = 0;
             return FALSE;
         } else {
             app->iap_connecting_timer++;
@@ -380,13 +312,15 @@ gboolean download_html(gpointer data) {
     /* The second stage */
     /* call curl_multi_perform for read weather data from Inet */
     if (curl_multi && CURLM_CALL_MULTI_PERFORM ==
-        curl_multi_perform(curl_multi, &num_transfers))
+        curl_multi_perform(curl_multi, &num_transfers)){
         return TRUE;            /* return to UI */
+        }
     /* The first stage */
     if (!curl_handle && !curl_handle_hour) {
 #ifndef RELEASE
         fprintf(stderr, "\n>>>>>>>>>>>First stage\n");
 #endif
+//        DEBUG_FUNCTION("\n>>>>>>>>>>>First stage\n");
         if (app->show_update_window)
             update_window = create_window_update();     /* Window with update information */
         /* get first station */
@@ -439,65 +373,64 @@ gboolean download_html(gpointer data) {
 #ifndef RELEASE
         fprintf(stderr, "\n>>>>>>>>>>>Third stage\n");
 #endif
-
+//        DEBUG_FUNCTION("\n>>>>>>>>>>>Third stage\n");
         /* The third stage */
         num_msgs = 0;
         while (curl_multi
                && (msg = curl_multi_info_read(curl_multi, &num_msgs))) {
             if (msg->msg == CURLMSG_DONE) {
-                /* Clean */
-                mret = curl_multi_remove_handle(curl_multi, curl_handle);       /* Delete curl_handle from curl_multi */
-                if (mret != CURLM_OK)
-                    fprintf(stderr, " Error remove handle %p\n",
+                if (msg->easy_handle == curl_handle){
+                    /* Clean */
+                    mret = curl_multi_remove_handle(curl_multi, curl_handle);       /* Delete curl_handle from curl_multi */
+                    if (mret != CURLM_OK)
+                       fprintf(stderr, " Error remove handle %p\n",
                             curl_handle);
-                if (app->config->show_weather_for_two_hours)
+                    curl_easy_cleanup(curl_handle);
+                    curl_handle = NULL;
+                    if (url) {
+                       g_free(url);
+                       url = NULL;
+                    }
+                    if (html_file.stream) {
+                        fclose(html_file.stream);
+                        html_file.stream = NULL;
+                    }
+
+                    if (html_file.filename) {
+                        g_free(html_file.filename);
+                        html_file.filename = NULL;
+                    }
+                }
+                if (msg->easy_handle == curl_handle_hour && app->config->show_weather_for_two_hours){
+
                     mret = curl_multi_remove_handle(curl_multi, curl_handle_hour);  /* Delete curl_handle from curl_multi */
-                if (mret != CURLM_OK)
-                    fprintf(stderr, " Error remove handle %p\n",
-                            curl_handle);
-
-                curl_easy_cleanup(curl_handle);
-                curl_handle = NULL;
-                if (app->config->show_weather_for_two_hours){
-                    curl_easy_cleanup(curl_handle_hour);
-                    curl_handle_hour = NULL;
-                }
-
-                if (url) {
-                    g_free(url);
-                    url = NULL;
-                }
-                if (html_file.stream) {
-                    fclose(html_file.stream);
-                    html_file.stream = NULL;
-                }
-
-                if (html_file.filename) {
-                    g_free(html_file.filename);
-                    html_file.filename = NULL;
-                }
-
-                if (app->config->show_weather_for_two_hours) {
-                    if (hour_url) {
-                        g_free(hour_url);
-                        hour_url = NULL;
-                    }
-                    if (html_file_hour.stream) {
-                        fclose(html_file_hour.stream);
-                        html_file_hour.stream = NULL;
-                    }
-                    if (html_file_hour.filename) {
-                        g_free(html_file_hour.filename);
-                        html_file_hour.filename = NULL;
+                    if (mret != CURLM_OK)
+                        fprintf(stderr, " Error remove handle %p\n",curl_handle);
+                        curl_easy_cleanup(curl_handle_hour);
+                        curl_handle_hour = NULL;
+                        if (hour_url) {
+                            g_free(hour_url);
+                            hour_url = NULL;
+                        if (html_file_hour.stream) {
+                            fclose(html_file_hour.stream);
+                            html_file_hour.stream = NULL;
+                        }
+                        if (html_file_hour.filename) {
+                            g_free(html_file_hour.filename);
+                            html_file_hour.filename = NULL;
+                        }
                     }
                 }
-
                 if (msg->data.result != CURLE_OK) {     /* Not success of the download */
                     if (app->show_update_window)
                         hildon_banner_show_information
                             (app->main_window, NULL,
                              _("Did not download weather"));
-                } else {        /* get next station url */
+                } else {
+
+                    if (curl_handle_hour || curl_handle)
+                        return TRUE; /* Continue downloading */
+                    /* get next station url */
                     if (!get_station_url(&url, &html_file, &hour_url, &html_file_hour, FALSE)) {        /* Success - all is downloaded */
                         if (app->show_update_window)
                             hildon_banner_show_information
@@ -507,13 +440,16 @@ gboolean download_html(gpointer data) {
 #ifndef RELEASE
                         fprintf(stderr,
                                 "\n>>>>>>>>>>>>>>End of update cycle\n");
+
 #endif
+//                        DEBUG_FUNCTION("End of update cycle");
                     } else {
 #ifndef RELEASE
                         fprintf(stderr,
                                 "\n>>>>>Url - %s, File - %s\n",
                                 url, html_file.filename);
 #endif
+//                        DEBUG_FUNCTION(html_file.filename);
                         /* set options for the curl easy handle */
                         curl_handle = weather_curl_init(curl_handle);
                         curl_easy_setopt(curl_handle, CURLOPT_URL, url);
@@ -548,10 +484,24 @@ gboolean download_html(gpointer data) {
                 }
                 curl_multi_cleanup(curl_multi);
                 curl_multi = NULL;
+                curl_handle_hour = NULL;
+                curl_handle = NULL;
+//                DEBUG_FUNCTION("This is the end");
                 app->flag_updating = 0;
                 return FALSE;   /* This is the end */
             }
         }
+        if (!curl_multi){
+            /* Clean all */
+            if (update_window) {
+                gtk_widget_destroy(update_window);
+                update_window = NULL;
+            }
+            curl_handle_hour = NULL;
+            curl_handle = NULL;
+            app->flag_updating = 0;
+            return FALSE;
+        }
         return TRUE;
     }
     app->flag_updating = 0;
@@ -608,10 +558,14 @@ get_station_url(gchar ** url, struct HtmlFile *html_file,
                            3, &station_source,
                            -1);
 /* !!! TODO: recode this */
-	if(!strcmp(station_source, "weather.com"))
-	    source = 0;
-	if(!strcmp(station_source, "rp5.ru"))
-	    source = 1;
+        /* Default weather.com */
+        if (station_source){
+            if(!strcmp(station_source, "weather.com"))
+                source = 0;
+            if(!strcmp(station_source, "rp5.ru"))
+                source = 1;
+        }else
+                source = 0;
         /* prepare url */
         if(weather_sources[source].url){
 	    *buffer = 0;
