@@ -1,3 +1,4 @@
+/* vim: set sw=4 ts=4 et: */
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
@@ -31,12 +32,27 @@
 #include "weather-common.h"
 #include <libxml/HTMLparser.h>
 /*******************************************************************************/
-gint parse_weather_file_data(const gchar *station_id, WeatherStationData *wsd);
-weather_com_parser *weather_parser_new_from_file(const gchar *filename);
+gint parse_weather_file_data(const gchar *station_id, gchar *station_source,
+					WeatherStationData *wsd,
+						gboolean selected_detail_weather);
+/* weather.com */
+weather_com_parser *weather_parser_new_from_file(const gchar *filename,
+							const gchar *encoding);
+
 gint parse_weather_com_xml(const gchar *station_id, weather_com_parser *parser,
 							WeatherStationData *wsd);
+gint parse_weather_com_xml_hour(const gchar *station_id, weather_com_parser *parser,
+							WeatherStationData *wsd);
+/* rp5.ru */
 gint parse_rp5_ru_xml(const gchar *station_id, weather_com_parser *parser,
 							WeatherStationData *wsd);
+void calculate_day_icon(gint cover, gint falls, gint drops, GSList **day,
+							gboolean store2day);
+/* wunderground.com */
+gint parse_wunderground_com_xml(const gchar *station_id,
+				weather_com_parser *parser,
+							WeatherStationData *wsd);
+/* underground.com */
 gint parse_underground_com_data(const gchar *station);
 void process_undeground_com_current_weather(const htmlNodePtr node);
 void process_undeground_com_forecast_weather(const htmlNodePtr node);
