@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006 Vlad Vasiliev
- * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * Copyright (C) 2008 Andrew Olmsted
  * 	for the code
  *        
@@ -186,7 +186,7 @@ GtkWidget* create_moon_phase_widget(GSList *current){
     return main_widget;
 }
 /*******************************************************************************/
-GtkWidget* 
+GtkWidget*
 create_time_updates_widget(GSList *current, gboolean change_color){
     GtkWidget	*main_widget = NULL,
     		*label_update;
@@ -319,12 +319,13 @@ gboolean make_hour_tab(GtkWidget *vbox){
 }
 /*******************************************************************************/
 GtkWidget *
-create_toolbar_box(gpointer exit_function, gpointer arg_exit_function)
+create_toolbar_box(GtkCallback exit_function, GtkWidget *window, gboolean fullscreen_button)
 {
     GtkWidget	*buttons_box = NULL,
                 *settings_button = NULL,
                 *refresh_button = NULL,
                 *about_button = NULL,
+                *maximize_button = NULL,
                 *close_button = NULL;
     /* Bottom buttons box */
     /*buttons_box = gtk_toolbar_new();
@@ -355,8 +356,13 @@ create_toolbar_box(gpointer exit_function, gpointer arg_exit_function)
     close_button = create_button_with_image(BUTTON_ICONS, "close", 40, FALSE, FALSE);
     g_signal_connect(G_OBJECT(close_button), "button-release-event",
                         G_CALLBACK(exit_function),
-                        (gpointer)arg_exit_function);
-
+                        (gpointer)window);
+    /* Fullscreen button */
+    /*maximize_button = create_tool_item(BUTTON_ICONS, "maximize", 40);*/
+    maximize_button = create_button_with_image(BUTTON_ICONS, "maximize", 40, FALSE, FALSE);
+    g_signal_connect(G_OBJECT(maximize_button), "button-release-event",
+                        G_CALLBACK(maximize_button_handler),
+                        (gpointer)window);
 /* Pack buttons to the buttons box */
     /*gtk_toolbar_insert(GTK_TOOLBAR(buttons_box), GTK_TOOL_ITEM(settings_button), -1);
     gtk_toolbar_insert(GTK_TOOLBAR(buttons_box), GTK_TOOL_ITEM(refresh_button), -1);
@@ -365,19 +371,24 @@ create_toolbar_box(gpointer exit_function, gpointer arg_exit_function)
     gtk_box_pack_start(GTK_BOX(buttons_box), settings_button, TRUE, TRUE, 5);
     gtk_box_pack_start(GTK_BOX(buttons_box), refresh_button, TRUE, TRUE, 5);
     gtk_box_pack_start(GTK_BOX(buttons_box), about_button, TRUE, TRUE, 5);
+    if (fullscreen_button)
+        gtk_box_pack_start(GTK_BOX(buttons_box), maximize_button, TRUE, TRUE, 5);
     gtk_box_pack_start(GTK_BOX(buttons_box), close_button, TRUE, TRUE, 5);
     return buttons_box;
 }
 /*******************************************************************************/
+void
 destroy_container (GtkWidget *widget, gpointer *data){
     gtk_widget_destroy(GTK_WIDGET(widget));
 }
 /******************************************************************************/
-gboolean
+void
 popup_switch_cb(GtkNotebook * nb, gpointer nb_page, gint page, gpointer data) {
     GtkWidget *vbox = NULL;
-    gint *day_number;
-    GtkWidget   *child;
+
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
 
     vbox = gtk_notebook_get_nth_page(nb, page);
 #ifdef CLUTTER
@@ -424,9 +435,9 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
+
     if (app->popup_window || app->flag_updating != 0)
         return FALSE;
-
 /* Debug */
 /*  time_start(); */
 /* day number */
@@ -541,9 +552,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
             gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
                                         hour_tab,
                                         gtk_label_new(_("Detailed")));
-#if defined CLUTTER
            g_idle_add((GSourceFunc)make_hour_tab,hour_tab);
-#endif
            add_item2object(&(app->tab_of_window_popup), (void*)hour_tab);
         }
     }
@@ -590,7 +599,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
         gtk_widget_show(notebook);
     }
 
-    buttons_box = create_toolbar_box(popup_close_button_handler,app->popup_window);
+    buttons_box = create_toolbar_box((GtkCallback)popup_close_button_handler, app->popup_window, FALSE);
 
     /* check if no data file for this station */
     if(gtk_notebook_get_n_pages(GTK_NOTEBOOK(notebook)) > 0){
@@ -631,7 +640,6 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
                      G_CALLBACK(popup_switch_cb), app->popup_window);
 #endif
 /* Show copyright widget */
-//    fprintf(stderr, "\n>>>>>>>>>>>>>>>>Source %s\n", app->config->current_station_source);
     copyright_box = gtk_event_box_new();
     gtk_container_add(GTK_CONTAINER(copyright_box),
                   create_copyright_widget(app->config->current_station_source, NULL));
@@ -681,6 +689,13 @@ void about_button_handler(GtkWidget *button, GdkEventButton *event,
     create_about_dialog();
 }
 /*******************************************************************************/
+void maximize_button_handler(GtkWidget *button, GdkEventButton *event, gpointer user_data){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    change_state_window(GTK_WIDGET(user_data));
+}
+/*******************************************************************************/
 void popup_close_button_handler(GtkWidget *button, GdkEventButton *event,
 								gpointer user_data){
 #ifdef DEBUGFUNCTIONCALL
@@ -958,7 +973,7 @@ GtkWidget* create_current_tab(GSList *current){
     GtkWidget   *main_widget = NULL,
                 *icon_text_hbox = NULL,
                 *text = NULL,
-		*icon_image = NULL;
+	*icon_image       = NULL;
     gchar       buffer[1024],
                 *units;
     const gchar *wind_units_str[] = { "m/s", "km/h", "mi/h" };
@@ -980,7 +995,7 @@ GtkWidget* create_current_tab(GSList *current){
     gtk_box_pack_start(GTK_BOX(icon_text_hbox), icon_image, TRUE, TRUE, 0);
     /* temperature */
     memset(buffer, 0, sizeof(buffer));
-    sprintf(buffer, "%s\n", hash_table_find(item_value(current, "title"), FALSE));
+    sprintf(buffer, "%s\n", (char *)hash_table_find(item_value(current, "title"), FALSE));
     sprintf(buffer + strlen(buffer), "%s",  _("Temperature: "));
     sprintf(buffer + strlen(buffer), "  %d\302\260",
                 ((app->config->temperature_units == CELSIUS) ?
@@ -1034,13 +1049,13 @@ GtkWidget* create_current_tab(GSList *current){
 
 	sprintf(buffer + strlen(buffer), "  %.2f %s,", tmp_pressure, units);
 	sprintf(buffer + strlen(buffer), "  %s\n",
-		    hash_table_find(item_value(current, "pressure_direction"), FALSE));
+		    (char *)hash_table_find(item_value(current, "pressure_direction"), FALSE));
     }
 /* wind */
     if( strcmp(item_value(current, "wind_direction"), "N/A") ){
 	sprintf(buffer + strlen(buffer), "%s", _("Wind:"));
 	sprintf(buffer + strlen(buffer), "  %s\n",
-		hash_table_find(item_value(current, "wind_direction"), FALSE));
+		(char *)hash_table_find(item_value(current, "wind_direction"), FALSE));
 	if( strcmp(item_value(current, "wind_speed"), "N/A") )
 	    sprintf(buffer + strlen(buffer), "%s", _("Speed:"));
 	    sprintf(buffer + strlen(buffer), "  %.2f %s\n",
