@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006 Vlad Vasiliev
- * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * Copyright (C) 2008 Andrew Olmsted
  * 	for the code
  *        
@@ -510,3 +510,26 @@ update_icons_set_base(const char *icon_set_name){
     app->config->icons_set_base = g_strdup(buffer);
 }
 /******************************************************************************/
+/* Fullscreen/Unfullscreen window */
+void
+change_state_window(GtkWidget *window){
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+    if (window){
+        if (gdk_window_get_state(window->window) &  GDK_WINDOW_STATE_FULLSCREEN)
+            gtk_window_unfullscreen (GTK_WINDOW(window));
+        else
+            gtk_window_fullscreen (GTK_WINDOW(window));
+    }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+} 
+/* For debugging  
+void write_log(char *string)
+{
+FILE *filelog; filelog=fopen("/tmp/omw.log","a+"); fprintf(filelog,"\n%s\n", string);fflush(filelog);fclose(filelog);
+}
+
+*/
